Struct finality_grandpa::voter::report::VoterState[−][src]

pub struct VoterState<Id: Eq + Hash> {
    pub background_rounds: HashMap<u64, RoundState<Id>>,
    pub best_round: (u64, RoundState<Id>),
}

Basic data struct for the current state of the voter in a form suitable for passing on to other systems.

Fields

background_rounds: HashMap<u64, RoundState<Id>>

Voting rounds running in the background.

best_round: (u64, RoundState<Id>)

The current best voting round.